import { UserCreator, LevelCreator } from './entities';
import fetch from './node-fetch';
/**
 * Configuration for the GD Client
 */
declare type Config = {
    /** The level of logging. 2 = verbose, 1 = warnings, 0 = off. Defaults to 1. */
    logLevel?: 0 | 1 | 2;
    /** The URL for the database. Defaults to http://boomlings.com/database. */
    dbURL?: string;
    /** The URL to use as a CORS proxy when making requests from a browser. Defaults to https://cors-anywhere.herokuapp.com/. Note it should have a trailing slash. */
    corsURL?: string;
    /** The fetch polyfill to use. Only necessary when fetch is not supported in the target environment. Defaults to node-fetch (if installed) */
    fetch: typeof fetch;
};
/**
 * Client for Geometry Dash requests.
 */
declare class Client {
    /** The database of Geometry Dash users */
    users: UserCreator;
    /** The database of Geometry Dash levels */
    levels: LevelCreator;
    /**
     * Creates a client for Geometry Dash requests.
     * @param config The configuration for the client.
     */
    constructor(config?: Config);
}
export default Client;
