"use strict";
/**
 * Zlib
 * @internal
 * @packageDocumentation
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.u8ToStr = exports.b64ToU8 = exports.decompress = void 0;
var zlib_1 = require("zlib");
/**
 * Decompress data of an arbitrary format
 * @param dat The data to decompress
 * @returns The decompressed data
 * @internal
 */
exports.decompress = function (dat) {
    return new Promise(function (res, rej) {
        var cb = function (err, dat) { return (err ? rej(err) : res(dat)); };
        if (dat[0] == 31 && dat[1] == 139 && dat[2] == 8)
            zlib_1.gunzip(dat, cb);
        else if ((dat[0] & 15) != 8 || dat[0] >> 4 > 7 || ((dat[0] << 8) | dat[1]) % 31)
            zlib_1.inflateRaw(dat, cb);
        else
            zlib_1.inflate(dat, cb);
    });
};
/**
 * Convert a string to a Uint8Array
 * @param str The Base64 string to convert
 * @returns The buffer containing the ASCII-encoded string
 * @internal
 */
exports.b64ToU8 = function (str) { return Buffer.from(str, 'base64'); };
/**
 * Convert a Uint8Array to a string
 * @param u8 The Uint8Array to convert
 * @returns The string containing the ASCII-decoded string
 * @internal
 */
exports.u8ToStr = function (u8) { return u8.toString('latin1'); };
